@@ -74,9 +74,11 @@ LIBKRIGING_EXPORT NoiseKriging::NoiseKriging(const arma::colvec& y,
                              + std::to_string(X.n_cols) + "), y: (" + std::to_string(y.n_elem) + ")");
 
   make_Cov(covType);
-  fit(y, X, noise, regmodel, normalize, optim, objective, parameters);
+  fit(y, noise, X, regmodel, normalize, optim, objective, parameters);
 }
 
+LIBKRIGING_EXPORT NoiseKriging::NoiseKriging(const NoiseKriging& other, ExplicitCopySpecifier) : NoiseKriging{other} {}
+
 // arma::mat XtX(arma::mat &X) {
 //   arma::mat XtX = arma::zeros(X.n_cols,X.n_cols);
 //   for (arma::uword i = 0; i < X.n_cols; i++) {
@@ -422,8 +424,9 @@ LIBKRIGING_EXPORT void NoiseKriging::fit(const arma::colvec& y,
       arma::vec w = dy2dX2_slope / sum(dy2dX2_slope);
       arma::mat steepest_dX_mean = arma::abs(m_dX) * w;
 
-      theta_lower = arma::max(theta_lower, Optim::theta_lower_factor / steepest_dX_mean);
-      theta_upper = arma::min(theta_upper, Optim::theta_upper_factor / steepest_dX_mean);
+      theta_lower = arma::max(theta_lower, Optim::theta_lower_factor * steepest_dX_mean);
+      // no, only relevant for inf bound: theta_upper = arma::min(theta_upper, Optim::theta_upper_factor *
+      // steepest_dX_mean);
       theta_lower = arma::min(theta_lower, theta_upper);
       theta_upper = arma::max(theta_lower, theta_upper);
     }
@@ -450,7 +453,7 @@ LIBKRIGING_EXPORT void NoiseKriging::fit(const arma::colvec& y,
     // arma::cout << "theta0:" << theta0 << arma::endl;
 
     // see https://github.com/cran/DiceKriging/blob/547135515e32fa0a37260b9cd01631c1b7a69a5b/R/kmNuggets.init.R#L30
-    double sigma2_variogram = 0.5 * arma::mean(dy2.elem(arma::find(dX2 > arma::median(dX2))));
+    double sigma2_variogram = 0.5 * arma::mean(dy2.elem(arma::find(dX2 >= arma::median(dX2))));
     double sigma2_lower = 0.1 * (sigma2_variogram - arma::max(m_noise));
     double sigma2_upper = 10 * (sigma2_variogram - arma::min(m_noise));
     arma::vec sigma20;
@@ -535,9 +538,9 @@ LIBKRIGING_EXPORT void NoiseKriging::fit(const arma::colvec& y,
         double sol_to_ub_theta = arma::min(arma::abs(gamma_tmp.head(d) - gamma_upper.head(d)));
         double sol_to_b_theta
             = Optim::reparametrize ? sol_to_ub_theta : sol_to_lb_theta;  // just consider theta lower bound
-        double sol_to_b_sigma2 = Optim::reparametrize
-                                     ? abs(gamma_tmp.at(d) - gamma_upper.at(d))
-                                     : abs(gamma_tmp.at(d) - gamma_lower.at(d));  // just consider sigma2 upper bound
+        double sol_to_b_sigma2
+            = Optim::reparametrize ? std::abs(gamma_tmp.at(d) - gamma_upper.at(d))
+                                   : std::abs(gamma_tmp.at(d) - gamma_lower.at(d));  // just consider sigma2 upper bound
         double sol_to_b = sol_to_b_theta < sol_to_b_sigma2 ? sol_to_b_theta : sol_to_b_sigma2;
         if ((retry < Optim::max_restart)       //&& (result.num_iters <= 2 * d)
             && ((sol_to_b < arma::datum::eps)  // we fastly converged to one bound
@@ -872,35 +875,40 @@ LIBKRIGING_EXPORT std::string NoiseKriging::summary() const {
     });
   };
 
-  oss << "* data";
-  oss << ((m_normalize) ? " (normalized): " : ": ") << m_X.n_rows << "x";
-  arma::rowvec Xmins = arma::min(m_X, 0);
-  arma::rowvec Xmaxs = arma::max(m_X, 0);
-  for (arma::uword i = 0; i < m_X.n_cols; i++) {
-    oss << "[" << Xmins[i] << "," << Xmaxs[i] << "]";
-    if (i < m_X.n_cols - 1)
-      oss << ",";
+  if (m_X.is_empty() || m_X.n_rows == 0) {  // not yet fitted
+    oss << "* covariance:\n";
+    oss << "  * kernel: " << m_covType << "\n";
+  } else {
+    oss << "* data";
+    oss << ((m_normalize) ? " (normalized): " : ": ") << m_X.n_rows << "x";
+    arma::rowvec Xmins = arma::min(m_X, 0);
+    arma::rowvec Xmaxs = arma::max(m_X, 0);
+    for (arma::uword i = 0; i < m_X.n_cols; i++) {
+      oss << "[" << Xmins[i] << "," << Xmaxs[i] << "]";
+      if (i < m_X.n_cols - 1)
+        oss << ",";
+    }
+    oss << " -> " << m_y.n_elem << "x[" << arma::min(m_y) << "," << arma::max(m_y) << "]\n";
+    oss << "* trend " << Trend::toString(m_regmodel);
+    oss << ((m_est_beta) ? " (est.): " : ": ");
+    colvec_printer(m_beta);
+    oss << "\n";
+    oss << "* variance";
+    oss << ((m_est_sigma2) ? " (est.): " : ": ");
+    oss << m_sigma2;
+    oss << "\n";
+    oss << "* covariance:\n";
+    oss << "  * kernel: " << m_covType << "\n";
+    oss << "  * range";
+    oss << ((m_est_theta) ? " (est.): " : ": ");
+    colvec_printer(m_theta);
+    oss << "\n";
+    oss << "  * noise: ";
+    colvec_printer(m_noise);
+    oss << "\n";
+    oss << "  * fit:\n";
+    oss << "    * objective: " << m_objective << "\n";
+    oss << "    * optim: " << m_optim << "\n";
   }
-  oss << " -> " << m_y.n_elem << "x[" << arma::min(m_y) << "," << arma::max(m_y) << "]\n";
-  oss << "* trend " << Trend::toString(m_regmodel);
-  oss << ((m_est_beta) ? " (est.): " : ": ");
-  colvec_printer(m_beta);
-  oss << "\n";
-  oss << "* variance";
-  oss << ((m_est_sigma2) ? " (est.): " : ": ");
-  oss << m_sigma2;
-  oss << "\n";
-  oss << "* covariance:\n";
-  oss << "  * kernel: " << m_covType << "\n";
-  oss << "  * range";
-  oss << ((m_est_theta) ? " (est.): " : ": ");
-  colvec_printer(m_theta);
-  oss << "\n";
-  oss << "  * noise: ";
-  colvec_printer(m_noise);
-  oss << "\n";
-  oss << "  * fit:\n";
-  oss << "    * objective: " << m_objective << "\n";
-  oss << "    * optim: " << m_optim << "\n";
   return oss.str();
 }
